/**
 * Module dependencies.
 */

var express = require('express'),
  shortener = require('./lib/short'),
  storage = require('./lib/storage'),
  stats = require('./lib/stats'),
  url = require('url'),
  os = require('os');

var app = module.exports = express.createServer();
var validate = require('./routes/validate')(app);
var routes = require('./routes/index')(app);


var port = process.env.PORT || 5000;

app.configure(function () {
  app.set('views', __dirname + '/views');
  app.use(express.cookieParser());
  app.use(express.session({ secret: 'super duper secret' }));
  app.set('view engine', 'jade');
  app.use(express.bodyParser());
  app.use(express.methodOverride());
  app.use(app.router);
  app.use(express.static(__dirname + '/public'));
  app.use(express.csrf());
  app.use(express.favicon(__dirname + '/public/favicon.ico'));
  app.dynamicHelpers({
    token:function (req, res) {
      return req.session._csrf;
    },
    host:function (req, res) {
      return req.headers.host;
    }
  });
});

app.configure('development', function () {
  app.use(express.errorHandler({ dumpExceptions:true, showStack:false }));
});

app.configure('production', function () {
  app.use(express.errorHandler({ dumpExceptions:false, showStack:true }));
});

// Routes
app.get('/', routes.index);
app.get('/d/:hash', routes.details);
app.get('/l/:hash', routes.link);
app.post('/new', [validate.url], routes.new);

app.listen(port, function () {
  console.log("Express server listening on port %d in %s mode", app.address().port, app.settings.env);
});
